
import os
import sys

_program_name = None

def set_program_name(name):

    global _program_name

    if name:

        _program_name = name
    else:

        _program_name = os.path.basename(sys.argv[0])

    return _program_name

def get_program_name():

    return _program_name

set_program_name(None)





__author__      =   'Matt Wilson'
__copyright__   =   'Copyright 2019, Synesis Software'
__credits__     =   [
        'Garth Lancaster',
        'Matt Wilson',
 ]
__email__       =   'matthew@synesis.com.au'
__license__     =   'BSD-3-Clause'
__maintainer__  =   'Matt Wilson'
__status__      =   'Beta'
__version__     =   '0.2.2'

from .conrep import abort, report
from .program_name import *
from .trace import enable_tracing, is_tracing_enabled, trace

